What's next?
============

Now that you are familiar with the basic concepts and Avocado usage, you can
write your tests.

As said before, you can write test on your favorite language. But if you would
like to use the Avocado libraries and facilities, you can use Python or Bash.

If you would like to move forward on Avocado, we prepared the *"Avocado Test
Writer's Guide"* for you. Have fun!
